Transformers
=================

This section is dedicated to a comprehensive array of functions for data transformation purposes. 
These functions are tailored to manipulate data in various formats, facilitating conversion between binary and contour representations, extraction of bounding boxes, generation of JSON data, and more.

.. toctree::
   :maxdepth: 1
   :caption: Functions:

   functions/transformers/binary2contours
   functions/transformers/contour2bbox
   functions/transformers/contours2json
   functions/transformers/ellipse2json
   functions/transformers/json2bbox
   functions/transformers/json2contours
   functions/transformers/json2dict
   functions/transformers/json2labels
   functions/transformers/json2mask
   functions/transformers/json2vgg
   functions/transformers/labels2contours
   functions/transformers/labels2listsOfPoints
   functions/transformers/mask2bbox
   functions/transformers/mask2json
   functions/transformers/positions2contour
   functions/transformers/vgg2json
   functions/transformers/list_of_points2json
